" syntax/frecord.vim

" Sbastien Millet, Mai 2009
" 23/05/09

" Fichier de surbrillance syntaxique pour le type frecord

if version < 600
	syntax clear
elseif exists("b:current_syntax")
	finish
endif

" Dcommenter pour afficher les ',' autrement, mais attention aux performances
" let b:highlight_commas=1

syntax clear
syntax case ignore

syntax match frecordComment /^#.*/ contains=frecordCommentDesc
syntax match frecordCommentDesc /^# Dir entry #\d\+:.*/ contained contains=frecordCommentDescStart,frecordCommentDescEnd
syntax match frecordCommentDescStart /^# \zsDir entry #\d\+\ze:/ contained
syntax match frecordCommentDescEnd /: \zs'.*'$/ contained

" En-tte
syntax region frecordHeader start=/\%^/ end=/^$/ contains=frecordHeaderInitStatement,frecordHeaderInitDirectory,frecordHeaderTitle
syntax match frecordHeaderTitle /\%^frecord$/ contained
syntax match frecordHeaderInitDirectory /^\(\f\|[ \\]\)\+\(\n\n\)\@=/ contained
syntax match frecordHeaderInitStatement /^\(fversion \d\d\?\.\d\)\|\(case=[01]\)\|\(hash=\w\+\)\|\(binmode=[01]\)$/ contained
	\ contains=frecordHeaderInitKeywords,frecordHeaderInitString
syntax keyword frecordHeaderInitKeywords fversion case hash binmode end_of_frecord contained
syntax match frecordHeaderInitString /[= ]\zs.*/ contained

" Corps
syntax region frecordBody start=/^$/ end=/\%$/ contains=frecordBodyEntryANY
syntax match frecordBodyEntryANY /^.*$/ contained contains=frecordBodyEntryOK,frecordBodyEndStatement,frecordComment

if exists("b:highlight_commas")
	" L'ensemble des dfinitions ci-dessous permet d'afficher les ',' (qui
	" sparent les champs) diffremment. Ils fonctionnent bien mais aboutissent 
	" un dlai de rafrachissement de l'affichage beaucoup trop long, >30 secondes
	" pour un fichier de 7 000 lignes.
	syntax match frecordBodyEntryOK /^\d\+,\d\+,\d\+,\d\+,\(\*\|-\|\x\+\),\d\+,\d\+,\d\+,\d\+,\(F\|D\),.*$/ contained
		\ contains=frecordBodyEntryNumber,frecordBodyEntryNameD,frecordBodyEntryNameF,frecordBodyComma
	syntax match frecordBodyEntryNumber /^\d\+/ contained
	syntax match frecordBodyEntryNameD /\(,D,\)\@<=[^,]\+$/ contained
	syntax match frecordBodyEntryNameF /\(,F,\)\@<=[^,]\+$/ contained
	syntax match frecordBodyComma /,/ contained
else
	" Ces dfinitions-l affichent les ',' normalement, mais elles permettent un
	" affichage bien plus efficace.
	syntax match frecordBodyEntryOK /^\d\+,\d\+,\d\+,\d\+,\(\*\|-\|\x\+\),\d\+,\d\+,\d\+,\d\+,\(F\|D\),.*$/ contained
		\ contains=frecordBodyEntryNumber,frecordBodyEntryNameD,frecordBodyEntryNameF
	syntax match frecordBodyEntryNumber /^\d\+\ze,/ contained
	syntax match frecordBodyEntryNameD /,D,\zs[^,]\+$/ contained
	syntax match frecordBodyEntryNameF /,F,\zs[^,]\+$/ contained contains=frecordBodyEntryNameFe
	syntax match frecordBodyEntryNameFe /[^\/]\+$/ contained
endif

syntax region frecordBodyEndStatement start=/^[[:digit:]]\+,END_OF_FRECORD$/ end=/\%$/ oneline
	\ contains=frecordHeaderInitKeywords,frecordBodyEntryNumber
syntax sync fromstart

hi def link frecordComment Comment
hi def link frecordCommentDesc Comment
hi def link frecordCommentDescStart Underlined
hi def link frecordCommentDescEnd Directory
hi def link frecordHeaderInitKeywords Statement
hi def link frecordHeaderInitStatement Statement
hi def link frecordHeaderInitDirectory NonText
hi def link frecordHeaderInitString String
hi def link frecordBodyEntryNumber LineNr
hi def link frecordBodyEntryNameD Directory
" hi def link frecordBodyEntryNameF ModeMsg
hi def link frecordBodyEntryNameFe ModeMsg
hi def link frecordType Type
hi def link frecordBodyEntryOK Normal
hi def link frecordBodyEntryANY Error
hi def link frecordHeader Error
hi def link frecordHeaderTitle Title

" Cf. remarque ci-dessus au sujet des dlais de rafrachissement de
" l'affichage
if exists("b:highlight_commas")
	hi def link frecordBodyComma Delimiter
endif

let b:current_syntax = "frecord"
